# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: ChatMode.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x0e\x43hatMode.proto\x12\x1e\x41\x63\x46unDanmu.Im.Cloud.Voice.Call*1\n\x08\x43hatMode\x12\x0e\n\nCM_UNKNOWN\x10\x00\x12\x08\n\x04\x43HAT\x10\x01\x12\x0b\n\x07MEETING\x10\x02\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'ChatMode_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _CHATMODE._serialized_start=50
  _CHATMODE._serialized_end=99
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: MessageRead.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import ChatTargetType_pb2 as ChatTargetType__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x11MessageRead.proto\x12\x1f\x41\x63\x46unDanmu.Im.Cloud.Data.Update\x1a\x14\x43hatTargetType.proto\"r\n\x0bMessageRead\x12\x13\n\x0bstrTargetId\x18\x01 \x01(\t\x12\x0f\n\x07readSeq\x18\x02 \x01(\x03\x12=\n\x0e\x63hatTargetType\x18\x03 \x01(\x0e\x32%.AcFunDanmu.Im.Message.ChatTargetTypeb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'MessageRead_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _MESSAGEREAD._serialized_start=76
  _MESSAGEREAD._serialized_end=190
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: CommonStateSignalWidget.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import WidgetItem_pb2 as WidgetItem__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x1d\x43ommonStateSignalWidget.proto\x12\nAcFunDanmu\x1a\x10WidgetItem.proto\"<\n\x17\x43ommonStateSignalWidget\x12!\n\x01\x61\x18\x01 \x03(\x0b\x32\x16.AcFunDanmu.WidgetItemb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'CommonStateSignalWidget_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMMONSTATESIGNALWIDGET._serialized_start=63
  _COMMONSTATESIGNALWIDGET._serialized_end=123
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: GroupInviteReqListResponse.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import GroupInviteRecord_pb2 as GroupInviteRecord__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n GroupInviteReqListResponse.proto\x12\x1b\x41\x63\x46unDanmu.Im.Cloud.Message\x1a\x17GroupInviteRecord.proto\"r\n\x1aGroupInviteReqListResponse\x12\x44\n\x0cinviteRecord\x18\x01 \x03(\x0b\x32..AcFunDanmu.Im.Cloud.Message.GroupInviteRecord\x12\x0e\n\x06offset\x18\x02 \x01(\tb\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'GroupInviteReqListResponse_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _GROUPINVITEREQLISTRESPONSE._serialized_start=90
  _GROUPINVITEREQLISTRESPONSE._serialized_end=204
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: KwaiStateSignalEcommerceCartItemPopup.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()




DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n+KwaiStateSignalEcommerceCartItemPopup.proto\x12\nAcFunDanmu\"\xb2\x01\n%KwaiStateSignalEcommerceCartItemPopup\x12\x44\n\x01\x61\x18\x01 \x01(\x0e\x32\x39.AcFunDanmu.KwaiStateSignalEcommerceCartItemPopup.unknown\x12\t\n\x01\x62\x18\x02 \x01(\t\x12\t\n\x01\x63\x18\x03 \x01(\t\x12\t\n\x01\x64\x18\x04 \x01(\t\x12\t\n\x01\x65\x18\x05 \x01(\t\"\x17\n\x07unknown\x12\x05\n\x01\x66\x10\x00\x12\x05\n\x01g\x10\x01\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'KwaiStateSignalEcommerceCartItemPopup_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _KWAISTATESIGNALECOMMERCECARTITEMPOPUP._serialized_start=60
  _KWAISTATESIGNALECOMMERCECARTITEMPOPUP._serialized_end=238
  _KWAISTATESIGNALECOMMERCECARTITEMPOPUP_UNKNOWN._serialized_start=215
  _KWAISTATESIGNALECOMMERCECARTITEMPOPUP_UNKNOWN._serialized_end=238
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: WidgetPictureInfo.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import ImageCdnNode_pb2 as ImageCdnNode__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n\x17WidgetPictureInfo.proto\x12\nAcFunDanmu\x1a\x12ImageCdnNode.proto\"N\n\x11WidgetPictureInfo\x12#\n\x01\x61\x18\x01 \x01(\x0b\x32\x18.AcFunDanmu.ImageCdnNode\x12\t\n\x01\x62\x18\x02 \x01(\x05\x12\t\n\x01\x63\x18\x03 \x01(\x05\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'WidgetPictureInfo_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _WIDGETPICTUREINFO._serialized_start=59
  _WIDGETPICTUREINFO._serialized_end=137
# @@protoc_insertion_point(module_scope)



# -*- coding: utf-8 -*-
# Generated by the protocol buffer compiler.  DO NOT EDIT!
# source: CommonActionSignalUserFollowAuthor.proto
"""Generated protocol buffer code."""
from google.protobuf.internal import builder as _builder
from google.protobuf import descriptor as _descriptor
from google.protobuf import descriptor_pool as _descriptor_pool
from google.protobuf import symbol_database as _symbol_database
# @@protoc_insertion_point(imports)

_sym_db = _symbol_database.Default()


import ZtLiveUserInfo_pb2 as ZtLiveUserInfo__pb2


DESCRIPTOR = _descriptor_pool.Default().AddSerializedFile(b'\n(CommonActionSignalUserFollowAuthor.proto\x12\nAcFunDanmu\x1a\x14ZtLiveUserInfo.proto\"f\n\"CommonActionSignalUserFollowAuthor\x12,\n\x08userInfo\x18\x01 \x01(\x0b\x32\x1a.AcFunDanmu.ZtLiveUserInfo\x12\x12\n\nsendTimeMs\x18\x02 \x01(\x03\x62\x06proto3')

_builder.BuildMessageAndEnumDescriptors(DESCRIPTOR, globals())
_builder.BuildTopDescriptorsAndMessages(DESCRIPTOR, 'CommonActionSignalUserFollowAuthor_pb2', globals())
if _descriptor._USE_C_DESCRIPTORS == False:

  DESCRIPTOR._options = None
  _COMMONACTIONSIGNALUSERFOLLOWAUTHOR._serialized_start=78
  _COMMONACTIONSIGNALUSERFOLLOWAUTHOR._serialized_end=180
# @@protoc_insertion_point(module_scope)
